<?php
/**
 * @file
 *   Hook implementations dealing with fields provided by list.module
 */

/**
 * Implements hook_commerce_bpc_MODULE_NAME_form_element_alter().
 */
function commerce_bpc_commerce_bpc_list_form_element_alter(&$form, &$form_state, $key) {
  $element = $form['static_values'][$key];
  $lang = $element['#language'];
  $field_name = $element[$lang]['#field_name'];
  $instance = field_info_instance('commerce_product', $field_name, $form['product_type']['#value']);

  if (!_commerce_bpc_get_value($instance, array('commerce_bpc', 'is_static'), FALSE)) {
    $element[$lang]['#type'] = 'checkboxes';
    // Get rid of 'none' option---user can just not pick any
    unset($element[$lang]['#options']['_none']);
    // Move to comibinations-fieldset
    $form['combinations'][$key] = $element;
    unset($form['static_values'][$key]);

    if (empty($form_state['commerce_bpc']['list']['combination_fields'])
    || !in_array($field_name, $form_state['commerce_bpc']['list']['combination_fields'])) {
    // record what we have done. As this hook may be run multiple times
    // due to form rebuilds, we need to make sure that we record each field
    // only once.
    $form_state['commerce_bpc']['list']['combination_fields'][] = $element[$lang]['#field_name'];

    }
  }
}
/**
 * Implements hook_commmerce_bpc_get_combinations().
 */
function commerce_bpc_commerce_bpc_get_combinations($form, &$form_state, &$combinations) {
  $new_combinations = array();
  $fields = $form_state['commerce_bpc']['list']['combination_fields'];
  foreach ($fields as $field_name) {
    $new_combinations = array();
    $langs = array_keys($form_state['values']['combinations'][$field_name]);
    $lang = reset($langs);
    $values = $form_state['values']['combinations'][$field_name][$lang];
    foreach ($combinations as $combination) {
      foreach ($values as $columns) {
        $new_combinations[] = $combination + array(
          $field_name => array($lang => array($columns)),
        );
      }
    }
    $combinations = $new_combinations;
  }
}
/**
 * Implements hook_commerce_bpc_token_info().
 *
 */
function commerce_bpc_commerce_bpc_token_info($instance) {
  $tokens = array();
  $field_name = $instance['field_name'];
  $field = field_info_field($field_name);
  if ($field['module'] == 'list' && !_commerce_bpc_get_value($instance, array('commerce_bpc', 'is_static'), FALSE)) {
    $options = list_allowed_values($field);
    $values = array_keys($options);
    $ex_value = reset($values);
    $tokens[$field_name . '-value'] = array(
      'name' => $instance['label'] . ' value',
      'description' => t('The internal value of the @field_label field, e.g. %value', array(
        '@field_label' => $instance['label'],
        '%value' => $ex_value,
      )),
    );
    $ex_value = reset($options);
    $tokens[$field_name . '-label'] = array(
      'name' => $instance['label'] . ' label',
      'description' => t('The label of the value of the @field_label field, e.g. %value', array(
        '@field_label' => $instance['label'],
        '%value' => $ex_value,
      )),    );
  }
  return $tokens;
}
/**
 * Implements hook_commerce_bpc_tokens().
 *
 */
function commerce_bpc_commerce_bpc_tokens($instance, $tokens, $data, $options) {
  $replacements = array();
  $sanitize = !empty($options['sanitize']);
  $field_name = $instance['field_name'];
  $field = field_info_field($field_name);
  if ($field['module'] == 'list' && !_commerce_bpc_get_value($instance, array('commerce_bpc', 'is_static'), FALSE)) {
    $field_items =  reset($data['bulk_data']['combination'][$field_name]);
    $field_value = $field_items[0]['value'];
    if (!empty($tokens[$field_name . '-value'])) {
      $replacements[$tokens[$field_name . '-value']] = $sanitize ? check_plain($field_value) : $field_value;
    }
    if (!empty($tokens[$field_name . '-label'])) {
      $labels = list_allowed_values($field);
      $label = $labels[$field_value];
      if (!empty($label)) {
        $replacements[$tokens[$field_name . '-label']] = $sanitize ? check_plain($label) : $label;
      }
    }
  }
  return $replacements;
}