<?php
/**
 * @file
 *   Token API implementations for Commerce bulk product creation module.
 */
/**
 * Implements hook_token_info().
 */
function commerce_bpc_token_info() {
  $token_type = array(
    'name' => t('Bulk Product'),
    'description' => t('Tokens related to bulk products.'),
    'needs-data' => 'bulk_data',
  );

  $bulk_product = array();
  foreach (commerce_product_types() as $bundle_name => $info) {
    if (commerce_bpc_valid_product_type($bundle_name)) {
      $bulk_product += commerce_bpc_token_info_by_product_type($bundle_name);
    }
  }
  return array(
    'types' => array('bulk_product' => $token_type),
    'tokens' => array('bulk_product' => $bulk_product),
  );
}

/**
 * Implements hook_tokens().
 */
function commerce_bpc_tokens($type, $tokens, array $data = array(), array $options = array()) {
  $sanitize = !empty($options['sanitize']);

  $replacements = array();
  if ($type == 'bulk_product' && !empty($data['bulk_data'])) {
    $product_type = $data['bulk_data']['product_type'];
    $replacements = commerce_bpc_tokens_by_product_type($product_type, $tokens, $data, $options);

  }
  return $replacements;
}
/**
 * Collects field-specific tokens for a given product type.
 *
 * @param $product_type
 *   The product type for which tokens should be requested.
 *
 * @return
 *   An array of token definitions.
 */
function commerce_bpc_token_info_by_product_type($product_type) {
  $tokens = array();
  $instances = field_info_instances('commerce_product', $product_type);
  foreach ($instances as $instance) {
    if (_commerce_bpc_get_value($instance, array('commerce_bpc', 'show_field'), TRUE)) {
      $tokens += module_invoke_all('commerce_bpc_token_info', $instance);
    }
  }
  return $tokens;
}
/**
 * Collects field-specific token replacement for a given product type.
 *
 * @param $product_type
 *   The product type for which tokens should be requested.
 *
 * @return
 *   An array of token definitions.
 */
function commerce_bpc_tokens_by_product_type($product_type, $tokens, $data, $options) {
  $replacements = array();
  $instances = field_info_instances('commerce_product', $product_type);
  foreach ($instances as $instance) {
    if (empty($instance['commerce_bpc'])
      || $instance['commerce_bpc']['show_field']) {
      $replacements += module_invoke_all('commerce_bpc_tokens', $instance, $tokens, $data, $options);
    }
  }
  return $replacements;
}